@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dslide" "0.6.2"
+(define-package "dslide" "20250102.819"
   "Domain Specific sLIDEs. Programmable Presentation."
   '((emacs "29.2"))
   :url "https://github.com/positron-solutions/dslide"
